@@ -23,9 +23,24 @@ FAILEDOPERATION = 'FailedOperation'
 # 另一个请求正在处理中，请稍后再试。
 FAILEDOPERATION_ANOTHERREQUESTPROCESSING = 'FailedOperation.AnotherRequestProcessing'
 
+# 获取鉴权策略失败。
+FAILEDOPERATION_GETPOLICYFAILED = 'FailedOperation.GetPolicyFailed'
+
+# 获取用户信息失败。
+FAILEDOPERATION_GETUSERINFOFAILED = 'FailedOperation.GetUserInfoFailed'
+
+# 获取工作组信息失败。
+FAILEDOPERATION_GETWORKGROUPINFOFAILED = 'FailedOperation.GetWorkGroupInfoFailed'
+
+# 授权失败。
+FAILEDOPERATION_GRANTPOLICYFAILED = 'FailedOperation.GrantPolicyFailed'
+
 # HTTP客户端请求失败。
 FAILEDOPERATION_HTTPCLIENTDOREQUESTFAILED = 'FailedOperation.HttpClientDoRequestFailed'
 
+# 取消授权失败。
+FAILEDOPERATION_REVOKEPOLICYFAILED = 'FailedOperation.RevokePolicyFailed'
+
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
@@ -53,12 +68,18 @@ INVALIDPARAMETER_INVALIDDESCRIPTION = 'InvalidParameter.InvalidDescription'
 # 无效的容错策略。
 INVALIDPARAMETER_INVALIDFAILURETOLERANCE = 'InvalidParameter.InvalidFailureTolerance'
 
+# 无效的过滤条件。
+INVALIDPARAMETER_INVALIDFILTERKEY = 'InvalidParameter.InvalidFilterKey'
+
 # 无效的工作组Id。
 INVALIDPARAMETER_INVALIDGROUPID = 'InvalidParameter.InvalidGroupId'
 
 # 无效的Offset值。
 INVALIDPARAMETER_INVALIDOFFSET = 'InvalidParameter.InvalidOffset'
 
+# 无效的CAM role arn。
+INVALIDPARAMETER_INVALIDROLEARN = 'InvalidParameter.InvalidRoleArn'
+
 # SQL解析失败。
 INVALIDPARAMETER_INVALIDSQL = 'InvalidParameter.InvalidSQL'
 
@@ -68,12 +89,18 @@ INVALIDPARAMETER_INVALIDSQLNUM = 'InvalidParameter.InvalidSQLNum'
 # 不支持的排序类型。
 INVALIDPARAMETER_INVALIDSORTBYTYPE = 'InvalidParameter.InvalidSortByType'
 
+# SparkAppParam无效。
+INVALIDPARAMETER_INVALIDSPARKAPPPARAM = 'InvalidParameter.InvalidSparkAppParam'
+
 # 存储位置错误。
 INVALIDPARAMETER_INVALIDSTORELOCATION = 'InvalidParameter.InvalidStoreLocation'
 
 # 无效的taskid。
 INVALIDPARAMETER_INVALIDTASKID = 'InvalidParameter.InvalidTaskId'
 
+# 无效的任务类型。
+INVALIDPARAMETER_INVALIDTASKTYPE = 'InvalidParameter.InvalidTaskType'
+
 # 无效用户名称。
 INVALIDPARAMETER_INVALIDUSERALIAS = 'InvalidParameter.InvalidUserAlias'
 
@@ -101,6 +128,12 @@ RESOURCENOTFOUND = 'ResourceNotFound'
 # 指定数据源连接没有找到。
 RESOURCENOTFOUND_DATASOURCENOTFOUND = 'ResourceNotFound.DatasourceNotFound'
 
+# 未找到结果路径。
+RESOURCENOTFOUND_RESULTOUTPUTPATHNOTFOUND = 'ResourceNotFound.ResultOutputPathNotFound'
+
+# 资源不可用。
+RESOURCEUNAVAILABLE = 'ResourceUnavailable'
+
 # 账号余额不足，无法执行SQL任务。
 RESOURCEUNAVAILABLE_BALANCEINSUFFICIENT = 'ResourceUnavailable.BalanceInsufficient'
 
